@@ -2,7 +2,7 @@
                          currencies.cpp  -  list of currencies
                              -------------------
     begin                : sam déc  1 23:40:19 CET 2001
-    copyright            : (C) 2001-2010 by Éric Bischoff
+    copyright            : (C) 2001-2011 by Éric Bischoff
     email                : ebischoff@nerim.net
  ***************************************************************************/
 
@@ -27,7 +27,8 @@
 
 static const char
 	*urlECB = "http://www.ecb.int/stats/eurofxref/eurofxref-daily.xml",
-	*urlNY_FRB = "http://www.newyorkfed.org/markets/fxrates/FXtoXML.cfm?FEXdate=%04d-%02d-%02d&FEXtime=1200";
+//	*urlNY_FRB = "http://www.newyorkfed.org/markets/fxrates/FXtoXML.cfm?FEXdate=%04d-%02d-%02d&FEXtime=1200",
+	*urlTG = "http://rss.timegenie.com/forex2.xml";
 
 // Constructor
 Currencies::Currencies()
@@ -160,21 +161,34 @@ void Currencies::addECBRates( int rounding )
 }
 
 // Add variable rates from New York Federal Reserve Bank
-void Currencies::addNY_FRBRates( int rounding )
+//void Currencies::addNY_FRBRates( int rounding )
+//{
+//	char url[128];
+//	QDate yesterday;
+//	KIO::TransferJob *job;
+//
+//	roundingMethod = rounding;
+//
+//	yesterday = QDate::currentDate().addDays(-1);
+//	// This is suboptimal: we should guess the date of latest working day at 12:00 in New York local time
+//	// Or much better: use a URL that does not depend on that date...
+//	sprintf(url, urlNY_FRB, yesterday.year(), yesterday.month(), yesterday.day());
+//	job = KIO::get( KUrl( url ), KIO::Reload, KIO::HideProgressInfo );
+//	connect( job, SIGNAL(data(KIO::Job *, const QByteArray &)),
+//		 this, SLOT(httpDataNY_FRB(KIO::Job *, const QByteArray &))
+//		);
+//}
+
+// Add variable rates from Time Genie foreign exchange
+void Currencies::addTGRates( int rounding )
 {
-	char url[128];
-	QDate yesterday;
 	KIO::TransferJob *job;
 
 	roundingMethod = rounding;
 
-	yesterday = QDate::currentDate().addDays(-1);
-	// This is suboptimal: we should guess the date of latest working day at 12:00 in New York local time
-	// Or much better: use a URL that does not depend on that date...
-	sprintf(url, urlNY_FRB, yesterday.year(), yesterday.month(), yesterday.day());
-	job = KIO::get( KUrl( url ), KIO::Reload, KIO::HideProgressInfo );
+	job = KIO::get( KUrl( urlTG ), KIO::Reload, KIO::HideProgressInfo );
 	connect( job, SIGNAL(data(KIO::Job *, const QByteArray &)),
-		 this, SLOT(httpDataNY_FRB(KIO::Job *, const QByteArray &))
+		 this, SLOT(httpDataTG(KIO::Job *, const QByteArray &))
 		);
 }
 
@@ -234,10 +248,78 @@ void Currencies::httpDataECB(KIO::Job *job, const QByteArray &array)
 }
 
 // Exchange rates received from New York Federal Reserve Bank
-void Currencies::httpDataNY_FRB(KIO::Job *job, const QByteArray &array)
-{
-	static const char *frbny = "http://www.newyorkfed.org/xml/schemas/FX/utility";
+//void Currencies::httpDataNY_FRB(KIO::Job *job, const QByteArray &array)
+//{
+//	static const char *frbny = "http://www.newyorkfed.org/xml/schemas/FX/utility";
+//
+//	job = 0; // Unused parameter
+//
+//	if ( array.size() )
+//	{
+//		variableRates += QString(array);
+//	}
+//	else
+//	{
+//		QDomDocument document( "rates" );
+//
+//		document.setContent( variableRates, true );
+//
+//		QDomNodeList ratesList = document.elementsByTagNameNS( frbny, "Series" );
+//		QString date;
+//		int num;
+//		double currencyPrecision;
+//
+//		for (int i = 0; i < ratesList.count(); i++)
+//		{
+//			QDomElement elt = ratesList.item(i).toElement();
+//			QDomNodeList dateElements = elt.elementsByTagNameNS( frbny, "TIME_PERIOD" ),
+//				     currencyElements = elt.elementsByTagNameNS( frbny, "CURR" ),
+//				     valueElements = elt.elementsByTagNameNS( frbny, "OBS_VALUE" );
+//			if (dateElements.count() == 1 && currencyElements.count() == 1 && valueElements.count() == 1)
+//			{
+//				QDomElement dateElement = dateElements.item(0).toElement(),
+//					    currencyElement = currencyElements.item(0).toElement(),
+//					    valueElement = valueElements.item(0).toElement();
+//				QString code(
+//					elt.attribute( "UNIT" ) == "USD" ?
+//					currencyElement.text():
+//					elt.attribute( "UNIT" )
+//				            );
+//				for (num = 0; num < numCurrencies; num++)
+//					if ( code == currency[num].code )
+//						break;
+//				if ( num < numCurrencies )
+//				{
+//					switch (roundingMethod)
+//					{
+//						case OFFICIAL_RULES:
+//							currencyPrecision = currency[num].officialRulesPrecision;
+//							break;
+//						case SMALLEST_COIN:
+//							currencyPrecision = currency[num].smallestCoinPrecision;
+//							break;
+//						default:
+//							currencyPrecision = 1.0;
+//					}
+//					if ( elt.attribute( "UNIT" ) != "USD" )
+//						currency[num].rate =
+//							valueElement.text().toDouble() / currencyPrecision;
+//					else currency[num].rate =
+//						( 1.0 / valueElement.text().toDouble() ) / currencyPrecision;
+//					currency[num].position = -2;
+//					if ( date.isNull() )
+//						date = dateElement.text();
+//				}
+//			}
+//		}
+//		variableRates = "";
+//		endDownload( dollarCurrency, date );
+//	}
+//}
 
+// Exchange rates received from Time Genie foreign exchange
+void Currencies::httpDataTG(KIO::Job *job, const QByteArray &array)
+{
 	job = 0; // Unused parameter
 
 	if ( array.size() )
@@ -246,11 +328,11 @@ void Currencies::httpDataNY_FRB(KIO::Job *job, const QByteArray &array)
 	}
 	else
 	{
-		QDomDocument document( "rates" );
+		QDomDocument document( "forex" );
 
 		document.setContent( variableRates, true );
 
-		QDomNodeList ratesList = document.elementsByTagNameNS( frbny, "Series" );
+		QDomNodeList ratesList = document.elementsByTagName( "currency" );
 		QString date;
 		int num;
 		double currencyPrecision;
@@ -258,19 +340,9 @@ void Currencies::httpDataNY_FRB(KIO::Job *job, const QByteArray &array)
 		for (int i = 0; i < ratesList.count(); i++)
 		{
 			QDomElement elt = ratesList.item(i).toElement();
-			QDomNodeList dateElements = elt.elementsByTagNameNS( frbny, "TIME_PERIOD" ),
-				     currencyElements = elt.elementsByTagNameNS( frbny, "CURR" ),
-				     valueElements = elt.elementsByTagNameNS( frbny, "OBS_VALUE" );
-			if (dateElements.count() == 1 && currencyElements.count() == 1 && valueElements.count() == 1)
+			if ( elt.hasAttribute( "code" ) && elt.hasAttribute( "rate" ) )
 			{
-				QDomElement dateElement = dateElements.item(0).toElement(),
-					    currencyElement = currencyElements.item(0).toElement(),
-					    valueElement = valueElements.item(0).toElement();
-				QString code(
-					elt.attribute( "UNIT" ) == "USD" ?
-					currencyElement.text():
-					elt.attribute( "UNIT" )
-				            );
+				QString code(elt.attribute( "code" ));
 				for (num = 0; num < numCurrencies; num++)
 					if ( code == currency[num].code )
 						break;
@@ -287,18 +359,13 @@ void Currencies::httpDataNY_FRB(KIO::Job *job, const QByteArray &array)
 						default:
 							currencyPrecision = 1.0;
 					}
-					if ( elt.attribute( "UNIT" ) != "USD" )
-						currency[num].rate =
-							valueElement.text().toDouble() / currencyPrecision;
-					else currency[num].rate =
-						( 1.0 / valueElement.text().toDouble() ) / currencyPrecision;
+					currency[num].rate =
+						elt.attribute( "rate" ).toDouble() / currencyPrecision;
 					currency[num].position = -2;
-					if ( date.isNull() )
-						date = dateElement.text();
 				}
 			}
 		}
 		variableRates = "";
-		endDownload( dollarCurrency, date );
+		endDownload( euroCurrency, date );
 	}
 }
